@@ -57,9 +57,11 @@ SETTINGS_DEFAULT = {
         'pt': 'pt-BR',
         'ro': 'ro-RO',
         'ru': 'ru-RU',
+        'sk': 'sk-SK',
         'sl': 'sl-SI',
         'sr': 'sr-RS',
         'sv': 'sv-SE',
+        'th': 'th-TH',
         'tr': 'tr-TR',
         'uk': 'uk-UA',
         'vi': 'vi-VN',
